@@ -1,15 +1,7 @@
 /*
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-ServerListView is derived from QTreeWidget and implements overly
-complex custom drag'n'drop behavior needed in ServerListDialog.
-
-Copyright (C) 2006 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2006 Eike Hein <hein@kde.org>
 */
 
 #ifndef SERVERLISTVIEW_H
@@ -19,6 +11,10 @@ Copyright (C) 2006 Eike Hein <hein@kde.org>
 
 #include <QDropEvent>
 
+/**
+ * ServerListView is derived from QTreeWidget and implements overly
+ * complex custom drag'n'drop behavior needed in ServerListDialog.
+ */
 class ServerListView : public QTreeWidget
 {
     Q_OBJECT
@@ -27,17 +23,21 @@ class ServerListView : public QTreeWidget
         explicit ServerListView(QWidget *parent);
         ~ServerListView() override;
 
-    private:
-        bool badDropSelection();
     Q_SIGNALS:
         void moved();
         void aboutToMove();
-        
-    protected:        
+
+    protected:
         void dragMoveEvent(QDragMoveEvent *e) override;
         void dragLeaveEvent(QDragLeaveEvent *) override;
         void dragEnterEvent(QDragEnterEvent *) override;
         void dropEvent(QDropEvent *event) override;
+
+    private:
+        bool badDropSelection();
+
+    private:
+        Q_DISABLE_COPY(ServerListView)
 };
 
 #endif
